-- 860 serializer

local is_buildroom = (os.execute("/usr/bin/grep -q 'option classless-routes 32,1,2,3,4,127,0,0,1' /var/db/dhclient.leases*") == 0)

local get_version = function()
	for line in io.lines("/etc/version") do
		pfversion = line
		break
	end
	for line in io.lines("/etc/version.patch") do
		if string.len(line) > 0 and line ~= "0" then
			pfversion = pfversion .. "-p" .. line
		end
		break
	end
	return pfversion
end

local get_bios_serial = function()
	os.execute ("/bin/kenv smbios.system.serial >>/tmp/serial")
	-- local tmpfile = io.open("/tmp/serial", "r")
	for line in io.lines("/tmp/serial") do
		serialnum = line
	end
	if serialnum == "123456789" then
		serialnum=""
	end
	return serialnum
end	

local get_wan_mac = function()
	if  App.state.netgate_model == "APU" then
		os.execute ("ifconfig re0 | awk '/ether/ {print $2}'| sed 's/://g' >>/tmp/wan_mac")
	elseif App.state.netgate_model == "XG-1540" or App.state.netgate_model == "XG-1541" then
		os.execute ("ifconfig ix0 | awk '/ether/ {print $2}'| sed 's/://g' >>/tmp/wan_mac")
	else
		os.execute ("ifconfig igb0 | awk '/ether/ {print $2}'| sed 's/://g' >>/tmp/wan_mac")
	end
	for line in io.lines("/tmp/wan_mac") do
		mac = line
	end
	if mac == nil then
		mac="000000000000"
	end
	return mac
end	

local get_wlan_mac = function()
	os.execute ("ifconfig ath0 | awk '/ether/ {print $2}'| sed 's/://g' >>/tmp/wlan_mac")
	for line in io.lines("/tmp/wlan_mac") do
		wlan_mac = line
	end
	if wlan_mac == nil then
		wlan_mac="000000000000"
	end
	return wlan_mac
end	

-- Calculate the "Unique ID" for support and tracking purposes
-- Hash the concatenated MAC addresses - Assume there are only physical
-- interfaces present during the build and use last 20 chars
local get_uniqueid = function()
	os.execute("/usr/sbin/gnid >/tmp/uniqueid")

	for line in io.lines("/tmp/uniqueid") do
		uniqueid = line
	end

	return uniqueid
end

-- Read available support types from prodtrack
local get_support_types = function()
	local support_types = {}

	if (os.execute("/usr/bin/fetch -o /tmp/support_types http://prodtrack.netgate.com/listspt 2>/dev/null") ~= 0) then
		return nil
	end

	local add_support_types_action = function(st_code, st_desc)
		table.insert(support_types,
		    {
			id = st_code,
			name = st_desc,
			effect = function()
				return st_code
			end
		    }
		)
	end

	for line in io.lines("/tmp/support_types") do
		pos = string.find(line, ",")
		if (pos ~= nil) then
			code = string.sub(line, 1, pos-1)
			desc = string.sub(line, pos+1)

			add_support_types_action(code, desc)
		end
	end

	return App.ui:present({
	    id = "select_support_type",
	    name = _("Select Support Type"),
	    short_desc = _("Select support type."),
	    actions = support_types,
	    role = "menu"
	}).result
end

return {   -- whole script
	id = "Serial_reg",
	name = _("Serial Registration Step"),
	-- req_state = {"storage"},
	effect = function(step)

		if not is_buildroom then
			return step:next()
		end

		local response = App.ui:present({
			id = "serial_register",
			name = _("Register Serial Number"),
			short_desc = _( "Enter the serial number " ),
			long_desc = _(
			"Help for Form",
			App.conf.product.name
			),

			fields = {
				{
					id = "product",
					name = _("Model"),
					short_desc = _("Selected Model")
				},
				{
					id = "serial",
					name = _("Serial"),
					short_desc = _("Enter the system serial")
				},
				{
					id = "order",
					name = _("Order Number"),
					short_desc = _("Enter the order number")
				},
				{
					id = "print_sticker",
					name = _("print sticker"),
					short_desc = _("Enter 0 to print, 1 to skip")
				},
				{
					id = "builder",
					name = _("builder"),
					short_desc = _("Builder Initials")
				},
			},
			datasets = {
				{
					serial = get_bios_serial(),
					order = "",
					product = App.state.netgate_model,
					print_sticker = "",
					builder = "",
				}
			},
			actions = {
				{
					id = "OK",
					name = _("OK")
				},
				{
					id = "cancel",
					name = _("Cancel")
				}
			},
		} )
		-- end Apu.ui.present
		if response.action_id == "OK" then
			local support_types = get_support_types()
			local wan_mac_addr = get_wan_mac()
			local wlan_mac_addr = get_wlan_mac()
			local release_ver = get_version()
			local product = response.datasets[1].product
			local serial = response.datasets[1].serial
			local order = response.datasets[1].order
			local print_sticker = response.datasets[1].print_sticker
			local builder = response.datasets[1].builder
			local uniqueid = get_uniqueid()

			postreq = "model=" .. product ..
				  "&serial=" .. serial ..
				  "&release=" .. release_ver ..
				  "&wan_mac=" .. wan_mac_addr ..
				  "&print=" .. print_sticker ..
				  "&uniqueid=" .. uniqueid ..
				  "&wlan_mac=" .. wlan_mac_addr ..
				  "&order=" .. order ..
				  "&builder=" .. builder ..
				  "&support=" .. support_types ..
				  "&submit=Submit"

			local cmds = CmdChain.new()
			cmds:add("/usr/bin/fetch -o /dev/null \"http://prodtrack.netgate.com/builder?" .. postreq .. "\"")

			if not cmds:execute() then
				App.ui:inform(_( "Serial Logging FAILED"))
				return
			end

			return step:next()
		else
			return
		end
	end
}
